@@ -6,19 +6,19 @@
  * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "atspi-private.h"
@@ -44,7 +44,25 @@ atspi_action_get_n_actions (AtspiAction *obj, GError **error)
 }
 
 /**
- * atspi_action_get_description:
+ * atspi_action_get_description: (rename-to atspi_action_get_action_description)
+ * @obj: a pointer to the #AtspiAction implementor to query.
+ * @i: an integer indicating which action to query.
+ *
+ * Get the description of '@i-th' action invocable on an
+ *      object implementing #AtspiAction.
+ *
+ * Returns: a UTF-8 string describing the '@i-th' invocable action.
+ *
+ * Deprecated: 2.10: Use atspi_action_get_action_description instead.
+ **/
+gchar *
+atspi_action_get_description (AtspiAction *obj, int i, GError **error)
+{
+  return atspi_action_get_action_description (obj, i, error);
+}
+
+/**
+ * atspi_action_get_action_description:
  * @obj: a pointer to the #AtspiAction implementor to query.
  * @i: an integer indicating which action to query.
  *
@@ -54,7 +72,7 @@ atspi_action_get_n_actions (AtspiAction *obj, GError **error)
  * Returns: a UTF-8 string describing the '@i-th' invocable action.
  **/
 gchar *
-atspi_action_get_description (AtspiAction *obj, int i, GError **error)
+atspi_action_get_action_description (AtspiAction *obj, int i, GError **error)
 {
   dbus_int32_t d_i = i;
   char *retval = NULL;
@@ -110,7 +128,25 @@ atspi_action_get_key_binding (AtspiAction *obj, gint i, GError **error)
 }
 
 /**
- * atspi_action_get_name:
+ * atspi_action_get_name: (rename-to atspi_action_get_action_name)
+ * @obj: a pointer to the #AtspiAction implementor to query.
+ * @i: an integer indicating which action to query.
+ *
+ * Get the name of the '@i-th' action invocable on an
+ *      object implementing #AtspiAction.
+ *
+ * Returns: the non-localized name of the action, as a UTF-8 string.
+ *
+ * Deprecated: 2.10: Use atspi_action_get_action_name instead.
+ **/
+gchar *
+atspi_action_get_name (AtspiAction *obj, gint i, GError **error)
+{
+  return atspi_action_get_action_name (obj, i, error);
+}
+
+/**
+ * atspi_action_get_action_name:
  * @obj: a pointer to the #AtspiAction implementor to query.
  * @i: an integer indicating which action to query.
  *
@@ -120,7 +156,7 @@ atspi_action_get_key_binding (AtspiAction *obj, gint i, GError **error)
  * Returns: the non-localized name of the action, as a UTF-8 string.
  **/
 gchar *
-atspi_action_get_name (AtspiAction *obj, gint i, GError **error)
+atspi_action_get_action_name (AtspiAction *obj, gint i, GError **error)
 {
   dbus_int32_t d_i = i;
   char *retval = NULL;
