@@ -6,19 +6,19 @@
  * Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* TODO: Auto-generate this file again
@@ -1240,6 +1240,18 @@ typedef enum {
  * @ATSPI_ROLE_CONTENT_INSERTION: Content previously inserted or proposed to be
  * inserted, e.g. in revision history or a content view providing suggestions
  * from reviewers. @Since: 2.34.
+ * @ATSPI_ROLE_MARK: A run of content that is marked or highlighted, such as for
+ * reference purposes, or to call it out as having a special purpose. If the
+ * marked content has an associated section in the document elaborating on the
+ * reason for the mark, then %ATSPI_RELATION_DETAILS should be used on the mark
+ * to point to that associated section. In addition, the reciprocal relation
+ * %ATSPI_RELATION_DETAILS_FOR should be used on the associated content section
+ * to point back to the mark. @Since: 2.36.
+ * @ATSPI_ROLE_SUGGESTION: A container for content that is called out as a proposed
+ * change from the current version of the document, such as by a reviewer of the
+ * content. This role should include either %ATSPI_ROLE_CONTENT_DELETION and/or
+ * %ATSPI_ROLE_CONTENT_INSERTION children, in any order, to indicate what the
+ * actual change is. @Since: 2.36
  *  @ATSPI_ROLE_LAST_DEFINED: Not a valid role, used for finding end of
  *  enumeration.
  *
@@ -1375,6 +1387,8 @@ typedef enum {
     ATSPI_ROLE_FOOTNOTE,
     ATSPI_ROLE_CONTENT_DELETION,
     ATSPI_ROLE_CONTENT_INSERTION,
+    ATSPI_ROLE_MARK,
+    ATSPI_ROLE_SUGGESTION,
     ATSPI_ROLE_LAST_DEFINED,
 } AtspiRole;
 
@@ -1383,7 +1397,7 @@ typedef enum {
  *
  * One higher than the highest valid value of #AtspiRole.
  */
-#define ATSPI_ROLE_COUNT (127+1)
+#define ATSPI_ROLE_COUNT (129+1)
 
 typedef enum
 {
